#
# spec file for package QtDMM
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           QtDMM
Version:        0.9.8
Release:        4.2
Summary:        DMM Readout Software Including a Configurable Recorder
License:        GPL-3.0-only
Group:          System/GUI/Other
URL:            https://github.com/tuxmaster/QtDMM
Source:         https://github.com/tuxmaster/QtDMM/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM QtDMM-0.9.2-newmodels.patch
Patch0:         QtDMM-0.9.2-newmodels.patch
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.5
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5SerialPort)
BuildRequires:  pkgconfig(Qt5Widgets)

%description
QtDMM is a DMM readout software including a configurable recorder. The
recorder features manual start, scheduled start (at a given time), and
triggered automatic start when given thresholds are reached.
Additionally, you can start an external application when given
thresholds are reached.

Although initially written for Metex (and compatible, like VOLTCRAFT)
multimeter, which use a 14-byte protocol, several more protocols have
been added. For more information about the currently supported DMMs,
refer to the preset table.

%prep
%setup -q
%patch0 -p1
# called lrelease in openSUSE
sed -i 's/lrelease-qt5/lrelease/' src/src.pro
sed -i 's/-fuse-ld=gold//' src/src.pro

%build
%qmake5
make %{?_smp_mflags}

%install
install -d %{buildroot}%{_bindir}
install bin/qtdmm %{buildroot}%{_bindir}/qtdmm
install -Dm 644 qtdmm.1 %{buildroot}%{_mandir}/man1/qtdmm.1
install -Dm 644 qtdmm.png %{buildroot}%{_datadir}/pixmaps/qtdmm.png
install -Dm 644 QtDMM.desktop %{buildroot}%{_datadir}/applications/QtDMM.desktop
%suse_update_desktop_file -G "DMM Readout Software" -r %{name} "Education;Engineering"

%files
%license LICENSE
%doc CHANGELOG README
%{_bindir}/qtdmm
%{_mandir}/man1/qtdmm.1%{?ext_man}
%{_datadir}/pixmaps/qtdmm.png
%{_datadir}/applications/QtDMM.desktop

%changelog
* Thu Apr 20 2023 Martin Liška <mliska@suse.cz>
- Drop using binutils-gold as it is unmaintained and
  will be dropped (boo#1210687).
* Tue Dec 27 2022 Andreas Schwab <schwab@suse.de>
- No gold on riscv64
* Wed Jul 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix the lrelease executable name.
* Fri Feb  9 2018 aloisio@gmx.com
- Update to version 0.9.8
  * Use gold linker.
  * Added HoldPeak HP-90EPC (tstenner).
  * Use pkgconfig for spec file.
  version 0.9.7
  * Added Voltcraft VC870 (Florian Evers)
  * Added VA symbols to display apparent power
  * Added cosphi symbols to display the power factor
  version 0.9.6
  * Code clean up
  * fix translation loading
  * Fix message handler
  * Fix file export (leading zero of the time stamp)
  * Fix console logging on Windows
  * Remove 1/10s sample rate -> don't work with most devices
  * Use infinity sign to set endless recoder
  * Fix hang of M-4660A
  version 0.9.5
  * Port to Qt5
  * Use C++14
  * Add translation support
- Switch to fork of the original project that supports Qt5
- Added QtDMM-0.9.2-newmodels.patch
* Sat Aug  2 2014 dmitry_r@opensuse.org
- Update to version 0.9.0
  * QtDMM was ported to Qt4.x
  * QtDMM was relicensed from GPL 2.0 to GPL 3
  * Added TekPower TP4000ZC / digitek DT4000ZC
  * Added PeakTech 3430
* Fri Jul 18 2008 hmacht@suse.de
- remove QtDMM-vc940.patch and QtDMM-fix-includes.patch
- update to 0.8.12:
  Version 0.8.12
  - Added PeakTech 4015A (Jochen Puchalla)
  - Added Tenma 72-7745 (Laurent Perez)
  - Bugfix McVoice M-980T (Erik Hobel)
  - Added Digitech QM1462 (Peter Halasz)
  - Added Digitek INO2513
  - Added Raio Shack 22-812 (Bruce Lilly)
  - Corrected typo in dmmgraph (Erik Hobel)
  Version 0.8.11
  - Mac OS X port
  Version 0.8.10
  - Added Sinometer MAS-343
  - Adedd PeakTech 3330
  - Bugfix in VC820 protocoll
  - Added Voltrcaft VC940
  - Added Digitech QM1537
  - Added Uni-Trend UT30A and UT30E
  - Added Digitek DT-9062
  - Confirmation Voltcraft M-3860
  - Added PeakTech 4360
  Version 0.8.9
  - Added Voltcraft M-3610D
  - Added Iso-Tech IDM 73
* Tue Oct 23 2007 hmacht@suse.de
- add QtDMM-fix-includes.patch to fix errors due to gcc4.3
* Mon Jul  2 2007 ckornacker@suse.de
- added VC940 support
* Fri Mar 30 2007 trenn@suse.de
- updated to version 0.8.8
  changelog copied from the project site:
- gcc 4.1 compatibility
- Added Digitech QM1538, MASTECH MAS-345, M-345pro, Voltcraft M-4650CR
- Context menu for graph
- Improved import
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 hmacht@suse.de
- update to version 0.8.7
- fix extra qualification in header file
* Mon Oct 17 2005 hmacht@suse.de
- created new package
